.. aiotools documentation master file, created by
   sphinx-quickstart on Tue Aug  1 15:09:44 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

aiotools Documentation
======================

**aiotools** is a set of idiomatic utilities to reduce asyncio boiler-plates.

.. toctree::
   :maxdepth: 2

   aiotools.cancel
   aiotools.context
   aiotools.defer
   aiotools.fork
   aiotools.func
   aiotools.iter
   aiotools.server
   aiotools.taskcontext
   aiotools.taskscope
   aiotools.supervisor
   aiotools.taskgroup
   aiotools.timer
   aiotools.utils


Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
